@@ -15,21 +15,19 @@
 #' @rdname nums
 #' 
 #' @export
+#' 
 
-nums = function(data) {
+nums <- function(data) {
   
-  data = as.data.frame(data)
+  data <- as.data.frame(data)
   
-  if( ncol(data) >= 2 ) {
+  if(ncol(data) >= 2) {
+    num <- sapply(data, is.numeric)
+    data.num <- data[num]
+    data.num <- as.data.frame(data.num)
     
-    num = sapply(data, is.numeric)
-    
-    data.num = data[num]
-    
-    data.num = as.data.frame(data.num)
-    
-  } else data.num = data
-  
+  } else {
+    data.num <- data
+  }
   return(data.num)
-  
 }
